@@ -19,7 +19,7 @@ Constants for attribute names of the various resources.
 
 Just a place to stash more magic strings.
 """
-from . import creds, server, secgroup, tags, database, ssh_key
+from . import creds, server, secgroup, tags, database, ssh_key, loadbalancer
 
 # stack attributes
 NAME = 'name'
@@ -30,3 +30,4 @@ STACK = 'stack'
 DEPLOYER_CREDS = 'deployer_credentials'
 KEY = 'key'
 SERVER_CLASS = 'server_class'
+PROVIDER = 'provider'
